﻿# Imagebutton example 2 by Jamey Stevenson
# This example shows a more detailed version of how you can use imagebuttons and screens
# to let the player click on objects in a scene.

# This block of python code defines some variables that we will use to track what the player is doing.
init python:
    # This boolean variable will be used to prevent imagebuttons from displaying hover effects
    # while text is being displayed.
    propsEnabled = False
    
    # This boolean variable will be used to track whether or not the player has picked up the key.
    keyCollected = False
    
    # This boolean variable will be used to track whether or not the player has opened the door.
    doorOpened = False

image bg wall = "brickWall.png"

# Imagebuttons must always be placed inside of a screen definition.
screen interactiveObjects:
    
    # We only want to have the door be interactive if the player hasn't opened it yet.
    # Once the door is open, we will display it using the add statement, which shows an image
    # without allowing the player to click on it.
    if doorOpened:
        add "doorOpen.png" xpos 207 ypos 45
    else:
        imagebutton auto "door_%s.png" xpos 207 ypos 45 focus_mask True action If(propsEnabled, Return ("door"))
    
    # We only want to display the key if the player has not collected it yet.
    if keyCollected == False:
        imagebutton auto "key_%s.png" xpos 650 ypos 200 focus_mask True action If(propsEnabled, Return ("key"))

# The game starts here.
label start:
    
    scene bg wall
    
    # Using the show screen statement causes Ren'Py to show our screen,
    # but doesn't allow the player to click on any of our imagebuttons.
    show screen interactiveObjects

    "Welcome!"
    "This example project is meant to show you how you can use imagebuttons."
    "Imagebuttons can be used to let the player click on objects in your game."
    "You can use imagebuttons and variables together to create more interesting obstacles like locked doors."
    "Give it a try!"
    
    # The while statement in Ren'Py works just like an if statement, except that it always goes back to the
    # beginning whenever it reaches the end of the block. Every time it starts over, it tests the condition
    # you provided to see if it is still true. If so, it does everything inside the block again.
    #
    # You can use this to create a loop and call the screen containing your interactive imagebuttons
    # over and over again until the player performs whatever game actions are required to advance.
    while True:
        # Set the propsEnabled variable to allow our imagebuttons to perform actions when clicked.
        $ propsEnabled = True
        
        # Call the screen containing our imagebuttons and wait until the player clicks on one of them.
        call screen interactiveObjects
        
        # Set the propsEnabled variable to false, because we don't want our imagebuttons to be clickable
        # until we restart the loop and call the screen again.
        $ propsEnabled = False
        
        # Tell Ren'Py to display the screen containing the imagebuttons, but not allow the player to click them.
        show screen interactiveObjects
    
        # After the player clicks on an imagebutton, the value returned by that imagebutton is stored inside
        # of the built-in "_return" variable. You can check this value to respond to what the player clicked.
        if _return == "key":
            $ keyCollected = True
            
            # Whenever you use the show screen command, it will refresh the visual state of
            # all the imagebuttons contained inside. In this case, it will cause the key to disappear.
            show screen interactiveObjects
            
            "You collected the key."
        
        elif _return == "door":
            if keyCollected:
                $ doorOpened = True
                
                # Whenever you use the show screen command, it will refresh the visual state of
                # all the imagebuttons contained inside. In this case, it will cause the door to open.
                show screen interactiveObjects
                
                "You used the key to open the door!"
                
                return
            else:
                "The door is locked."

    return
